#ifndef GLUCOSE_CONTROL_STRUCTS_H__
#define GLUCOSE_CONTROL_STRUCTS_H__

typedef struct
{
    bool glucBatteryLow;
    bool glucSensorMalfunction;
    bool glucSampleTooSmall;
    bool glucStripInsertError;
    bool glucIncorrectStrip;
    bool glucResultHigLow;
    bool glucTempHighLow;
    bool glucReadInterrupted;
    bool glucDeviceFault;
    bool glucTimeFault;
    bool glucMultipleBond;

} s_glucoseFeature;

typedef struct
{
    bool batteryLow;
    bool sensorMalfunction;
    bool sampleTooSmall;
    bool stripInsertError;
    bool incorrectStrip;
    bool resultTooHigh;
    bool resultTooLow;
    bool tempTooHigh;
    bool tempTooLow;
    bool readInterrupted;
    bool deviceFault;
    bool timeFault;
}  s_glucsensorStatus;

enum GlucMsmtType
{
    GlucMsmtTypeReservedLow,
    GlucMsmtTypeCapillaryWholeBlood,
    GlucMsmtTypeCapillaryPlasma,
    GlucMsmtTypeVenousWholeBlood,
    GlucMsmtTypeVenousPlasma,
    GlucMsmtTypeArterialWholeBlood,
    GlucMsmtTypeArterialPlasma,
    GlucMsmtTypeUndeterminedWholeBlood,
    GlucMsmtTypeUndeterminedPlasma,
    GlucMsmtTypeInterstitialFluid,
    GlucMsmtTypeControlSolution,
};

enum GlucSampLoc
{
    GlucSampLocReservedLow,
    GlucSampLocFinger,
    GlucSampLocAlternateSiteTest,
    GlucSampLocEarlobe,
    GlucSampLocControlSolution,
    GlucSampLocReservedHigh,
    GlucSampLocNotAvailable,
};

typedef struct
{
    bool hasTimeOffset;
    bool hasGlucose;
    bool glucoseUnits;    // "false" = "mg/dL" "true" = "mmol/L"
    bool hasStatus;
    bool contextFollows;
    char baseTime[14];    // Format YYYYMMDDHHmmSS
    int timeOffset;        // minutes
    char msmtValue[8];    // As string to give precision - 4 digits from 0 to 2047
    enum GlucMsmtType msmtType;
    enum GlucSampLoc sampleLocation;
    s_glucsensorStatus sensorStatus;
} s_glucmsmtChar;

enum GlucCarbsId
{
    GlucCarbsIdReservedLow,
    GlucCarbsIdBreakfast,
    GlucCarbsIdLunch,
    GlucCarbsIdDinner,
    GlucCarbsIdSnack,
    GlucCarbsIdDrink,
    GlucCarbsIdSupper,
    GlucCarbsIdBrunch,
};
enum GlucMealCtx
{
    GlucMealCtxReservedLow,
    GlucMealCtxPreprandial,
    GlucMealCtxPostprandial,
    GlucMealCtxFasting,
    GlucMealCtxCasual,
    GlucMealCtxBedtime,
};
enum GlucTester
{
    GlucTesterReservedLow,
    GlucTesterSelf,
    GlucTesterHealthProfessional,
    GlucTesterLabTest,
    GlucTesterNotAvailable,
};
enum GlucHealth
{
    GlucHealthReservedLow,
    GlucHealthMinorIssues,
    GlucHealthMajorIssues,
    GlucHealthDuringMenses,
    GlucHealthUnderStress,
    GlucHealthNoIssues,
    GlucHealthNotAvailable,
};
enum GlucMedsId // Insulin
{
    GlucMedsIdReservedLow,
    GlucMedsIdRapidActing,
    GlucMedsIdShortActing,
    GlucMedsIdIntermediateActing,
    GlucMedsIdLongActing,
    GlucMedsIdPreMixedAction,
};
typedef struct
{
    bool carbsPresent;
    bool mealPresent;
    bool testerHealthPresent;
    bool exercisePresent;
    bool medicationPresent;
    bool medicationUnits; // false = milligrams true = milliters
    bool hbA1cPresent;
    bool extendedFlagsPresent;
    enum GlucCarbsId carbsId;
    char carbsAmount[8]; // as string in grams 4 digits from 0 to 2047
    enum GlucMealCtx mealContext;
    enum GlucTester tester;
    enum GlucHealth health;
    enum GlucMedsId medicationId;
    char medicationAmount[8]; // As string to give precision - 4 digits from 0 to 2047
    char hbA1c[8];  // As string to give precision - 4 digits from 0 to 2047 in percent
} s_glucmsmtContextChar;

typedef struct
{
    s_glucoseFeature* glucoseFeature;
    s_glucmsmtChar* msmts[16];
    s_glucmsmtContextChar* msmtContexts[16];
} s_glucoseParams;

#endif // GLUCOSE_CONTROL_STRUCTS_H__