#ifndef HEARTRATE_CONTROL_STRUCTS_H__
#define HEARTRATE_CONTROL_STRUCTS_H__

#define HR_FORMAT_FLAG 1
#define HR_SENSORCONTACT_NOCONTACT_FLAG 2
#define HR_SENSORCONTACT_CONTACT_FLAG 6
#define HR_ENERGY_EXPENDED_FLAG 8
#define HR_RR_INTERVALS_FLAG 16

#include <stdbool.h>
#include <DISControlStructs.h>

typedef struct
{
    unsigned char hrFormatFlag;             // if 0 Heart Rate Value is a UINT8. Units: beats per minute (bpm)
                                            // if HR_FORMAT_FLAG  then Heart Rate Value is a UINT16. Units: beats per minute (bpm)
    unsigned char hrSensorContactFlag;      // if HR_SENSORCONTACT_NOCONTACT_FLAG then contact supported but no contact detected
                                            // if HR_SENSORCONTACT_CONTACT_FLAG then contact supported and there is contact
    unsigned char energyExpendedStatusFlag; // if HR_ENERGY_EXPENDED_FLAG the energy expended present. Units: kilo Joules
    unsigned char RRntervalPresentFlag;     // if HR_RR_INTERVALS_FLAG then RR present
    short int heartRate;                    // beats per minute
    short int energyExpended;               // nutritional calories
    short int *rrIntervals;                 // array contains the RR intervals (in units of 1024 ticks per second)
    int numberOfRrIntervals;
} s_hrMsmtChar;


typedef struct
{
    char* deviceName;                   // The friendly name of the device, also used as the file name to save the data for this hr peripheral
    unsigned char bluetoothAddress[6];  // The Bluetooth Address to use
    s_disCharValues *disCharValues;     // The characteristic values of the DIS. DIS not created if NULL
    int numberOfMsmts;                  // Number of measurements to send
    s_hrMsmtChar **hrMsmtChar;          // Array of pointers to Heart Rate Measurement Characteristic structs
    bool invokeServiceChanged;          // If true, a service changed event will be indicated on connection
} s_hrParams;

#endif // HEARTRATE_CONTROL_STRUCTS_H__